require "import"
import "android.widget.*"
import "android.view.*"
import "android.content.Context"
import "android.content.Intent"
import "android.net.Uri"
import "android.text.Editable"
import "android.text.TextWatcher"

activity.setTitle("Bangla text analyzer Developed by Md. Abdur rahim Powered by All tech Barisal") -- हेडिंग

-- ग्लोबल वेरिएबल्स
local activity = activity
local editText
local characterCountTextView, wordCountTextView, lineCountTextView, sentenceCountTextView, paragraphCountTextView

-- यूट्यूब और व्हाट्सएप लिंक
local youtubeLink = "https://youtube.com/@alltechbarisal?si=0pZztLGQky6CNCCD"
local whatsappGroupLink = "https://chat.whatsapp.com/Lbay0UuPslmJ0y8eVIUzon"

-- लेआउट बनाएँ
function onCreate(savedInstanceState)
    -- स्क्रॉल व्यू और लेआउट सेटअप
    local scrollView = ScrollView(activity)
    local layout = LinearLayout(activity)
    layout.setOrientation(LinearLayout.VERTICAL)

    -- टेक्स्ट इनपुट
    editText = EditText(activity)
    editText.setHint("Enter your text here") -- बंगाली में टेक्स्ट
    layout.addView(editText)

    -- PasteButton
    local pasteButton = Button(activity)
    pasteButton.setText("Paste") -- बंगाली में बटन टेक्स्ट
    pasteButton.onClick = function(view)
        local clipboard = activity.getSystemService(Context.CLIPBOARD_SERVICE)
        local clip = clipboard.getPrimaryClip()
        if clip and clip.getItemCount() > 0 then
            local pasteData = clip.getItemAt(0).getText()
            if pasteData then
                editText.setText(pasteData)
            end
        end
    end
    layout.addView(pasteButton)

    -- यूट्यूब बटन
    local youtubeButton = Button(activity)
    youtubeButton.setText("ours  YouTube channel View") -- बंगाली में यूट्यूब लिंक
    youtubeButton.onClick = function(view)
        openLink(youtubeLink)
    end
    layout.addView(youtubeButton)

    -- व्हाट्सएप बटन
    local whatsappButton = Button(activity)
    whatsappButton.setText("ours WhatsApp community View") -- बंगाली में व्हाट्सएप लिंक
    whatsappButton.onClick = function(view)
        openLink(whatsappGroupLink)
    end
    layout.addView(whatsappButton)

    -- टेक्स्ट काउंटर्स
    characterCountTextView = TextView(activity)
    characterCountTextView.setText("Number of letters: 0") -- बंगाली में कैरेक्टर काउंट
    layout.addView(characterCountTextView)

    wordCountTextView = TextView(activity)
    wordCountTextView.setText("Number of words:: 0") -- बंगाली में वर्ड काउंट
    layout.addView(wordCountTextView)

    lineCountTextView = TextView(activity)
    lineCountTextView.setText("Line Number: 0") -- बंगाली में लाइन काउंट
    layout.addView(lineCountTextView)

    sentenceCountTextView = TextView(activity)
    sentenceCountTextView.setText("Number of sentences: 0") -- बंगाली में सेंटेंस काउंट
    layout.addView(sentenceCountTextView)

    paragraphCountTextView = TextView(activity)
    paragraphCountTextView.setText("Paragraph number: 0") -- बंगाली में पैराग्राफ काउंट
    layout.addView(paragraphCountTextView)

    scrollView.addView(layout)
    activity.setContentView(scrollView)

    -- टेक्स्ट इनपुट के लिए रियल-टाइम काउंटिंग
    editText.addTextChangedListener(TextWatcher {
        onTextChanged = function(s, start, before, count)
            updateCounters()
        end
    })
end

-- लिंक खोलने का फंक्शन
function openLink(link)
    local intent = Intent(Intent.ACTION_VIEW, Uri.parse(link))
    activity.startActivity(intent)
end

-- काउंटर्स अपडेट करने का फंक्शन
function updateCounters()
    local text = editText.getText().toString()

    -- अक्षर संख्या
    local characterCount = string.len(text)
    characterCountTextView.setText("Number of letters: " .. characterCount)

    -- शब्द संख्या
    local wordCount = 0
    for word in string.gmatch(text, "%S+") do
        wordCount = wordCount + 1
    end
    wordCountTextView.setText("Number of words: " .. wordCount)

    -- पंक्ति संख्या
    local lineCount = 0
    for line in string.gmatch(text, "[^\n]*\n?") do
        lineCount = lineCount + 1
    end
    lineCountTextView.setText("Line Number: " .. lineCount)

    -- वाक्य संख्या (सरल अनुमान)
    local sentenceCount = 0
    for sentence in string.gmatch(text, "[%.!?]") do
        sentenceCount = sentenceCount + 1
    end
    sentenceCountTextView.setText("Number of sentences: " .. sentenceCount)

    -- पैराग्राफ संख्या (सरल अनुमान)
    local paragraphCount = 0
    for paragraph in string.gmatch(text, "[^\n]*\n?") do
        if string.match(paragraph, "%S") then
            paragraphCount = paragraphCount + 1
        end
    end
    paragraphCountTextView.setText("Paragraph number: " .. paragraphCount)
end